# Burningkeys

Burningkeys is a lightweight python script to invoke certain commands using hotkeys. This cli is meant mainly for
coding. For example you might be editing in a basic text editor and would like to invoke a linter on your project. Well
now you can set that up.

Basically I don't like vim, but would like to have vim.